Consumer Reports Online
Description: Product reviews and Ratings on cars, appliances, electronics and more from Consumer Reports

Donate |
A-Z Index

## Support
Consumer Safety

### Make your tax-deductible year-end gift today!

Support Consumer Reports' work to protect and advocate for consumers.
More

Quick poll

What to look for in a fake Christmas tree.

## E-mail Newsletters

FREE e-mail Newsletters! Choose from cars, safety, health, and more!
Already signed-up?
Manage your newsletters here too.

## Latest From Consumer Reports

FOOD PROCESSOR REVIEWS
10 top-rated small appliances that cost $50 or less These attractive deals won’t bust your budget this holiday season.
CAMERA REVIEWS
Say cheese! Best digital cameras at any price Top picks for point-and-shoots to high-end advanced models.
CARS NEWS
GM issues new ignition keys to eliminate shifter interference Affected models include 2014 and 2015 full-sized pickups and SUVs.
CAR RELIABILITY GUIDE
Owner satisfaction: Would you buy your car again? Our exclusive survey covers 350,000 vehicles from one to three years old.
WASHING MACHINE REVIEWS
Washer-dryer pairs that cleaned up in our tough tests Check out these pairs when you need new laundry equipment.
WHERE TO BUY EYEGLASSES
How to get a great-looking pair of cheap glasses Use these tips to avoid overpaying on your next pair of specs.
More Articles & News

## Connect

Discuss products and safety
with subscribers and fans
Discuss products

### Follow us on:

## Videos

See all videos

## Consumer Reports Magazine

Best everyday products. SUV road tests. Credit score woes. Car recall advice. Special report on gluten. And more.
Inside the January 2015 issue

## Cars

New Car Price Report
Find out what the dealers don't want you to know! Get dealer pricing information on a new car with the New Car Price Report.

Order Your Report

## Mobile

Get Ratings on the go and compare products while you shop.

Learn more